@@ -13,23 +13,25 @@ class UTGenerator(Generator):
         task='UT',
         max_trans=1,
         fields='x',
-        transformation_methods=None,
-        transformation_config=None,
+        trans_methods=None,
+        trans_config=None,
         return_unk=True,
-        subpopulation_methods=None,
-        subpopulation_config=None,
+        sub_methods=None,
+        sub_config=None,
         attack_methods=None,
-        validate_methods=None
+        validate_methods=None,
+        **kwargs
     ):
         super().__init__(
             task=task,
             max_trans=max_trans,
             fields=fields,
-            transformation_methods=transformation_methods,
-            transformation_config=transformation_config,
+            trans_methods=trans_methods,
+            trans_config=trans_config,
             return_unk=return_unk,
-            subpopulation_methods=subpopulation_methods,
-            subpopulation_config=subpopulation_config,
+            sub_methods=sub_methods,
+            sub_config=sub_config,
             attack_methods=attack_methods,
-            validate_methods=validate_methods
+            validate_methods=validate_methods,
+            **kwargs
         )
